@@ -11,6 +11,7 @@ line.
 """
 import argparse
 import logging
+import os
 import sys
 from pathlib import Path
 from typing import List, Optional
@@ -118,6 +119,10 @@ def _setup_logging(
         logger.addHandler(console_handler)
 
 
+_DANGER_ENV = "PYNGUIN_DANGER_AWARE"
+"""People may wipe their disk, so we give them a heads up."""
+
+
 def main(argv: List[str] = None) -> int:
     """Entry point for the CLI of the Pynguin automatic unit test generation framework.
 
@@ -133,6 +138,16 @@ def main(argv: List[str] = None) -> int:
         An integer representing the success of the program run.  0 means
         success, all non-zero exit codes indicate errors.
     """
+    if _DANGER_ENV not in os.environ:
+        print(
+            f"""Environment variable '{_DANGER_ENV}' not set.
+Aborting to avoid harming your system.
+Please refer to the documentation
+(https://pynguin.readthedocs.io/en/latest/user/quickstart.html)
+to see why this happens and what you must do to prevent it."""
+        )
+        return -1
+
     install()
     if argv is None:
         argv = sys.argv
